# Ribomala
Ribomala is a python package to efficiently analyze ribosome profiling data.

# Features
- Minimal set of, well maintained, dependencies.
- Uses python polars for lightening fast data processing
- OS agnostic
- Provides ribosome reading frame and periodicity distribution.
- Provides ribosome occupancy values for E-, P- and A-sites

# Installation

```bash

pip install ribomala

```

# Documentation

Documentation can be accessed [here](https://ps-puneetsharma.github.io/ribomala/). It will walk you through ribosome profiling data analysis from scratch.
